run_tardis_machine_replay_from_config

Function run_tardis_machine_replay_from_config 

pub async fn run_tardis_machine_replay_from_config(
    config_filepath: &Path,
) -> Result<()>
Runs the Tardis Machine replay from a JSON configuration file.

Errors

Returns an error if reading or parsing the config file fails, or if any downstream replay operation fails.

Panics

Panics if unable to determine the output path (current directory fallback fails).